@@ -11,6 +11,7 @@
   #define _ATOMS_LISTS
 #endif
 
+#define LISTS_VERSION (0x100*0 | 19)
 
 #ifndef __Common_H_INCLUDED
   #include "common.h"
@@ -146,7 +147,7 @@ public: temp_list(int n):list(n) {};
 	};
 
 
-//Constant list could be feed by char** array
+/// Constant list could be feed by char** array
 class const_list:public list
 	{
 protected:	//Disable access to these operators
@@ -156,8 +157,11 @@ protected:	//Disable access to these operators
 	int operator|=(const char *str)	   {return(-1);};
 	void erase()	{};
 
-public: const_list(const char **data,int count)  {pstr=const_cast<char**>(data);NumAlloc=0;NumUsed=count;};
+public: const_list(const char **data,int count)  {pstr=const_cast<char**>(data);NumUsed=count;};  //NumAlloc=0;
+        const_list(const const_list &cl) {pstr=cl.pstr;NumUsed=cl.NumUsed;}
 	~const_list()			   {pstr=NULL;}
+
+        const_list &operator=(const const_list &cl) {pstr=cl.pstr;NumUsed=cl.NumUsed;return *this;}
 	};
 
 
