@@ -1,5 +1,5 @@
 /*******************************************************
-* Unit:    matrix            release 0.9               *
+* Unit:    matrix            release 0.10              *
 * Purpose: general manipulation with matrices          *
 * Licency: GPL or LGPL                                 *
 * Copyright: (c) 1998-2021 Jaroslav Fojtik             *
@@ -1049,7 +1049,7 @@ int i;
  do {
     //prev=result(0,0);
     result+=temp;
-    temp=temp*(*this)*(1.0/i);
+    temp=temp*(*this)*((FLOAT)1/i);
     //if(prev==result(0,0)) break;
     } while(++i<=MaxIterations);
 return(result);
