@@ -286,23 +286,46 @@ int I;
   if((Suffix=(uint16_t *)calloc(4096,sizeof(uint16_t)))==NULL) goto FINISH;
 
   while(!feof(f))
-    {
+  {
     I = fgetc(f);
     //fpos_t pos;fgetpos(f,&pos);printf("%lX,%X\n",pos,I);
     switch(I)
        {
        case EOF:goto FINISH;	//Next Byte
 
-       case 0x21:			   	/*?-Extended Bloks*/
+       case 0x21:				// '!' GIF Extended Blok
 	  if(fread(OutCode,1,2,f)!=2) goto FINISH;
 	   //      WriteLn('Extension block type: ',Outcode^[0]);}
 	  CodeSize = OutCode[1];
+
+#ifndef NO_EXTENSIONS
+	  if(OutCode[0]==0xFE && CodeSize>0)		// Read comment extension
+          {
+            PropertyItem *Prop = new PropertyItem("comment");
+            if(Prop)
+            {
+	      while(CodeSize>0)
+              {
+	        Nacteno = fread(OutCode,1,CodeSize+1,f);
+	        if(Nacteno!=CodeSize+1) {delete(Prop);goto FINISH;}
+                Prop->Append(OutCode,CodeSize);
+                CodeSize = OutCode[CodeSize];
+              } while(CodeSize>0);
+	      break;
+              if(Prop->Data && Prop->DataSize>0)
+		  Img.Properties.AddProp(Prop);
+              else
+                  delete(Prop);
+            }
+	  }
+#endif
+			// dummy read blob
 	  while(CodeSize>0)
-	     {
-	     Nacteno=fread(OutCode,1,CodeSize+1,f);
+	  {
+	     Nacteno = fread(OutCode,1,CodeSize+1,f);
 	     if(Nacteno!=CodeSize+1) goto FINISH;
-	     CodeSize=OutCode[CodeSize];
-	    }
+	     CodeSize = OutCode[CodeSize];
+	  }
 	  break;
 
        case 0x2C:
@@ -438,7 +461,7 @@ int I;
 
      default:goto FINISH;
      }
-  }
+ }
 
 FINISH:
  //fclose(F);
@@ -478,7 +501,7 @@ int ret = 1;
 }
 
 
-static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL)
+static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL, bool Ver89=false)
 {
 /* typedef struct {
     Word LocalScreenWidth,	// The width of the image - the first byte is the least significant: "01 00" would be 1 as "00 01" would be 256
@@ -492,7 +515,7 @@ static int StoreGIFHeader(FILE *f, const Image &Img, APalette *GlobPalette=NULL)
     Byte PixelAspectRatio;	// Aspect Ratio - this is ignored nowadays.
 } ScreenDescriptor; */
 
-  if((fwrite("GIF87a", 6, 1, f)) != 1) return -2;
+  if((fwrite(Ver89?"GIF89a":"GIF87a", 6, 1, f)) != 1) return -2;
   WrWORD_LoEnd(Img.Raster->Size1D,f);
   WrWORD_LoEnd(Img.Raster->Size2D,f);
 
@@ -1018,8 +1041,21 @@ bool NeedLocalPalette = false;
   else
     NeedLocalPalette = true;
 
+  const PropertyItem *PropComment;
+#ifndef NO_EXTENSIONS
+  CurrentImage = &Img;
+  do
+  {
+    unsigned ix=0;
+    PropComment = Img.Properties.Find("comment",ix);
+    CurrentImage = CurrentImage->Next;
+  } while(CurrentImage!=NULL && PropComment==NULL);
+#else
+  PropComment = NULL;
+#endif
+
 	/* Write GIF signature */
-  int ret = StoreGIFHeader(f,Img,GlobPalette);
+  int ret = StoreGIFHeader(f, Img, GlobPalette, PropComment!=NULL);
 
   if(GlobPalette)
   {
@@ -1040,6 +1076,28 @@ bool NeedLocalPalette = false;
   CurrentImage = &Img;
   do
   {
+#ifndef NO_EXTENSIONS
+    {
+      unsigned count=0;
+      PropComment = Img.Properties.Find("comment",count);
+      if(PropComment!=NULL && PropComment->Data!=NULL)
+      {
+        char Blob[2] = {0x21, 0xFE};
+        fwrite(Blob,1,2,f);
+        count = PropComment->DataSize;
+        uint8_t *Offs = (uint8_t*)PropComment->Data;
+        do
+        {
+          Blob[0] = (count>255) ? 255 : count;
+          fwrite(Blob,1,1,f);
+          fwrite(Offs,1,Blob[0],f);
+	  count -= Blob[0];
+          Offs += Blob[0];
+        } while(Blob[0]!=0);
+      }
+    }
+#endif
+
     fputc(',',f);	// Separator
     ID.Left = 0;
     ID.Top = 0;
