@@ -6,7 +6,7 @@
 #include "stringa.h"
 
 #include "wp2latex.h"
-#include "images/raster.h"
+#include "raster.h"
 #include "images/vecimage.h"
 #include "images.h"
 #include "cp_lib/cptran.h"
@@ -163,6 +163,8 @@ TconvertedPass1_xMF::TconvertedPass1_xMF(void)
   YExtent = XExtent = 0;
 	// PSS has its own CTOR.
   PSS.FillPattern = FILL_SOLID;
+  memset(&PSS.FillColor,0xFF,sizeof(PSS.FillColor));	// Default fill color should be white.
+  PSS.LineStyle = 1;
   PSS.FontSizeW = PSS.FontSize = 1100/2.66f;		// Default font size [mm]
   PsNativeCP = GetTranslator("internalTOcp1276");
   PsNativeSym = GetTranslator("internalTOsymbol");
